:github_url:

.. _faq:

FAQ
===

Is *scherbelberg* secure?
-------------------------

There is no easy yes/no answer. See chapter on :ref:`security <security>` for a detailed description.

Where do I report bugs?
-----------------------

See chapter on :ref:`reporting bugs and issues <bugs>`.

Why not simply use the Dask cloud provider?
-------------------------------------------

You are free to do so. However, *scherbelberg* follows a different motivation and serves different use cases than the `Dask cloud provider package`_, see the :ref:`chapter about scherbelberg <about>`

.. _Dask cloud provider package: https://cloudprovider.dask.org/en/latest/
